// Authors: Stefan Haustein (SH), Michael Kroll (MK)
//

import java.awt.*;
import java.awt.event.*;
import de.kawt.*;


public class Lotto extends KAWTlet implements ActionListener {

    private Frame frame = new Frame ("Lotto v1.0");
    
    public Lotto () {
        MenuBar menuBar = new MenuBar ();
        Menu menu = new Menu ("Info");
        MenuItem mi = new MenuItem ("About Lotto");
        mi.addActionListener (this);
        menu.add (mi);

        mi = new MenuItem ("Memory");
        mi.addActionListener (this);
        menu.add (mi);
	
	    menuBar.add (menu);
	    
        frame.setMenuBar (menuBar);
        
        Panel menuPanel = new Panel(new GridLayout(4, 1));
        Button lottoRandomButton = new Button("LottoRandom");
        lottoRandomButton.addActionListener(this);
        Button histogramButton = new Button("LottoHistogram");
        histogramButton.addActionListener(this);
        Button recommandButton = new Button("LottoRecommand");
        recommandButton.addActionListener(this);
        Button calcButton = new Button("LottoCalculate");
        calcButton.addActionListener(this);
        
        menuPanel.add(lottoRandomButton);
        menuPanel.add(histogramButton);
        menuPanel.add(recommandButton);
        menuPanel.add(calcButton);
        
        frame.add(menuPanel);
	    frame.addWindowListener (new Closer (this));

        frame.pack ();
    }

    public void startApp () {
	    frame.show ();
    }


    public void destroyApp (boolean uncond) {
	    frame.dispose ();
    }
    
    
    public void actionPerformed (ActionEvent e) {
	  String cmd = e.getActionCommand ();
	  if (cmd.equals ("About Lotto")) {
	      OptionDialog.showMessageDialog 
		  (frame, "For information about Lotto, please visit\nhttp://www.Lotto.com");
	  } else if (cmd.equals ("Memory")) {
   	      int count = 0;
	      long free0 = Runtime.getRuntime().freeMemory ();
	      long free = free0;
	      while (true) {
		    Runtime.getRuntime().gc();
		    long newFree = Runtime.getRuntime().freeMemory ();
		    if (newFree <= free) break;
		    count ++;
		    free = newFree;
	      }
	      OptionDialog.showMessageDialog (frame, "ini: "+free0+"\ngc"+count+": "+free);
	  } else if (cmd.equals ("LottoRandom")) {
	      this.destroyApp(true);
	      new LottoRandom ().startApp ();
      } else if (cmd.equals ("LottoHistogram")) {
	      this.destroyApp(true);
	      new LottoHistogram ().startApp ();
	      notifyDestroyed ();
      } else if (cmd.equals ("LottoRecommand")) {
	      this.destroyApp(true);
	      new LottoRecommand ().startApp ();
      } else if (cmd.equals ("LottoCalculate")) {
	      this.destroyApp(true);
	      new LottoCalc ().startApp ();
      }
    
    }

    public static void main (String [] argv) {
        new Lotto ().startApp ();
    }
        
}